from enum import StrEnum


class PlinkKeyword(StrEnum):
    FILE = "--file"  # Input file in PLINK's text format (ped/map)
    BFILE = "--bfile"  # Input file in binary format (bed/bim/fam)
    OUT = "--out"  # Output file prefix
    CHR_SET = "--chr-set"  # Set the number of chromosomes
    CHR = "--chr"  # Select a specific chromosome
    GENO = "--geno"  # Missing genotype filter
    MIND = "--mind"  # Individual missingness filter
    MAF = "--maf"  # Minor allele frequency filter
    AUTOSOME = "--autosome"  # Restrict to autosomal chromosomes
    WE = "--we"  # Whole-exome association test
    MAKE_BED = "--make-bed"  # Create binary fileset
    COW = "--cow"  # Cluster all data in the same genetic cluster
    VERSION = "--version"  # Display version information
    PCA = "--pca"  # Principal component analysis
    RECODE = "--recode"  # Recode genotype data
    OUTPUT_CHR = "--output-chr"  # Specify chromosome output format
    ZERO_CLUSTER = "--zero-cluster"  # Zero out cluster assignments
    SPLIT_X = "--split-x"  # Split chromosome X into pseudoautosomal and non-pseudoautosomal regions # noqa
    MERGE_X = "--merge-x"  # Merge chromosome X pseudoautosomal and non-pseudoautosomal regions # noqa
    SET_ME_MISSING = "--set-me-missing"  # Set ME (missing) genotype calls
    FILL_MISSING_A2 = "--fill-missing-a2"  # Fill missing genotype calls with allele 2
    SET_MISSING_VAR_IDS = "--set-missing-var-ids"  # Set missing variant IDs
    UPDATE_MAP = "--update-map"  # Update genetic map positions
    UPDATE_IDS = "--update-ids"  # Update individual IDs
    FLIP = "--flip"  # Flip strands of specified SNPs
    FLIP_SCAN = "--flip-scan"  # Detect strand inconsistencies
    KEEP_ALLELE_ORDER = "--keep-allele-order"  # Keep original allele order
    INDIV_SORT = "--indiv-sort"  # Sort individuals in output
    WRITE_COVAR = "--write-covar"  # Write covariate file
    MERGE = "--merge"  # Merge multiple PLINK files
    MERGE_LIST = "--merge-list"  # Merge multiple PLINK files from a list
    BMERGE = "--bmerge"  # Merge binary PLINK files
    WRITE_SNPLIST = "--write-snplist"  # Write SNP list
    LIST_DUPLICATE_VARS = "--list-duplicate-vars"  # List duplicate variants
    FREQ = "--freq"  # Allele frequency report
    MISSING = "--missing"  # Missing data report
    TEST_MISHAP = "--test-mishap"  # Test for mishap
    HARDY = "--hardy"  # Hardy-Weinberg equilibrium test
    MENDEL = "--mendel"  # Mendelian error report
    HET = "--het"  # Heterozygosity report
    IBC = "--ibc"  # Inbreeding coefficient
    CHECK_SEX = "--check-sex"  # Check sex consistency
    IMPUTE_SEX = "--impute-sex"  # Impute sex based on genotype
    FST = "--fst"  # FST calculation
    INDEP = "--indep"  # LD-based SNP pruning
    R = "--r"  # Pairwise SNP correlation (r)
    R2 = "--r2"  # Pairwise SNP correlation (r^2)
    SHOW_TAGS = "--show-tags"  # Show tags for SNPs
    BLOCKS = "--blocks"  # LD block detection
    DISTANCE = "--distance"  # Genetic distance calculation
    MAKE_GRM_BIN = (
        "--make-grm-bin"  # Create genetic relationship matrix in binary format
    )
    REL_CUTOFF = "--rel-cutoff"  # Relatedness cutoff
    IBS_TEST = "--ibs-test"  # Identity-by-state test
    GENOME = "--genome"  # Genome-wide identity-by-state report
    HOMOZYG = "--homozyg"  # Runs of homozygosity analysis
    CLUSTER = "--cluster"  # Cluster analysis
    MDS_PLOT = "--mds-plot"  # Multi-dimensional scaling plot
    NEIGHBOUR = "--neighbour"  # Nearest neighbor analysis
    ASSOC = "--assoc"  # Basic association test
    MODEL = "--model"  # Genetic model association test
    MH = "--mh"  # Mantel-Haenszel test
    MH2 = "--mh2"  # Mantel-Haenszel test for meta-analysis
    HOMOG = "--homog"  # Homogeneity test
    GXE = "--gxe"  # Gene-environment interaction test
    LINEAR = "--linear"  # Linear regression
    LOGISTIC = "--logistic"  # Logistic regression
    DOSAGE = "--dosage"  # Dosage data processing
    LASSO = "--lasso"  # LASSO regression
    TEST_MISSING = "--test-missing"  # Test for missingness
    TDT = "--tdt"  # Transmission disequilibrium test
    DFAM = "--dfam"  # DFAM analysis
    QFAM = "--qfam"  # Quantitative family-based association test
    TUCC = "--tucc"  # Test for unrelated case/control
    ANNOTATE = "--annotate"  # SNP annotation
    CLUMP = "--clump"  # LD clumping
    GENE_REPORT = "--gene-report"  # Gene-based report
    META_ANALYSIS = "--meta-analysis"  # Meta-analysis
    FAST_EPITASIS = "--fast-epistasis"  # Fast epistasis test
    EPITASIS = "--epistasis"  # Epistasis test
    TWOLOCUS = "--twolocus"  # Two-locus test
    SCORE = "--score"  # Polygenic risk score calculation
    R_PLUGIN = "--R"  # R plugin for advanced analyses
    MAKE_PHENOTYPE = "--make-phenotype"  # Create phenotype file
    MAKE_KINSHIP = "--make-kinship"  # Create kinship matrix
    UPDATE_SEX = "--update-sex"  # Update sex information
    UPDATE_PHENO = "--update-pheno"  # Update phenotype information
    EXTRACT = "--extract"  # Extract specific SNPs
    EXCLUDE = "--exclude"  # Exclude specific SNPs
    REMOVE = "--remove"  # Remove specific individuals
    KEEP = "--keep"  # Keep specific individuals
    CLUSTERING = "--clustering"  # Perform clustering analysis
    FILTER = "--filter"  # Apply filters to data
    CHECK_DUPLICATES = "--check-duplicates"  # Check for duplicate individuals
    SUMSTATS = "--sumstats"  # Summary statistics
    NOMEANIMPUTE = "--nomeanimpute"  # No mean imputation for missing data
    CI = "--ci"  # Confidence interval for association tests
    GRM = "--grm"  # Genetic relationship matrix
    INDIV_LIST = "--indiv-list"  # List of individuals
    BED2FAM = "--bed2fam"  # Convert BED file to FAM format
    EXTRACT_FAM = "--extract-fam"  # Extract individuals from FAM file
